@@ -19,18 +19,24 @@
  * is" without express or implied warranty.
  *
  * @author     Ryuma Ando <ando@ecomas.co.jp>
- * @copyright  2003-2008 PgPool Global Development Group
- * @version    SVN: $Id: common.php,v 1.11 2011/10/11 07:39:04 anzai Exp $
+ * @copyright  2003-2012 PgPool Global Development Group
+ * @version    SVN: $Id$
  */
 
 require_once('version.php');
 require_once('libs/Smarty.class.php');
 error_reporting(E_ALL);
 
-define('SESSION_LOGIN_USER', 'loginUser');
+define('SESSION_LOGIN_USER',          'loginUser');
 define('SESSION_LOGIN_USER_PASSWORD', 'md5pass');
-define('SESSION_LANG', 'lang');
-define('SESSION_MESSAGE', 'message');
+define('SESSION_LANG',                'lang');
+define('SESSION_MESSAGE',             'message');
+
+function versions()
+{
+    return array('3.2', '3.1', '3.0',
+                 '2.3', '2.2', '2.1', '2.0');
+}
 
 session_start();
 
@@ -44,6 +50,7 @@ define('SMARTY_COMPILE_DIR', dirname(__FILE__) . '/templates_c' );
  * Initialize Smartry
  */
 $tpl = new Smarty();
+//$tpl->error_reporting = E_ALL & ~E_NOTICE;
 $tpl->assign('version', $version);
 
 if (!file_exists('conf/pgmgt.conf.php')) {
@@ -58,10 +65,14 @@ require_once('conf/pgmgt.conf.php');
 /**
  * Check login
  */
-$isLogin = FALSE;
-if (isset($_SESSION[SESSION_LOGIN_USER])) {
-    $isLogin = TRUE;
-    $tpl->assign('isLogin', $isLogin);
+$tpl->assign('isLogin', isset($_SESSION[SESSION_LOGIN_USER]));
+$tpl->assign('isHelp', FALSE);
+
+// If old pgmgt.conf is used, _PGPOOL2_VERSION doen't exist.
+// This defined var exists from pgpoolAdmin 3.2.
+if (!defined('_PGPOOL2_VERSION')) {
+    $versions = versions();
+    define('_PGPOOL2_VERSION', $versions[0]);
 }
 
 /**
@@ -69,6 +80,7 @@ if (isset($_SESSION[SESSION_LOGIN_USER])) {
  */
 $errors = array();
 if (!defined('_PGPOOL2_LANG') ||
+    !defined('_PGPOOL2_VERSION') ||
     !defined('_PGPOOL2_CONFIG_FILE') ||
     !defined('_PGPOOL2_PASSWORD_FILE') ||
     !defined('_PGPOOL2_COMMAND') ||
@@ -214,7 +226,7 @@ function isParallelMode()
 {
     $params = readConfigParams(array('parallel_mode'));
 
-    if ($params['parallel_mode'] == 'true') {
+    if (isTrue($params['parallel_mode'])) {
         return TRUE;
     } else {
         return FALSE;
@@ -228,21 +240,7 @@ function isParallelMode()
  */
 function NodeActive($num)
 {
-    $healthCheckDb = 'template1';
-
-    $params = readHealthCheckParam();
-
-    $healthCheckUser = $params['health_check_user'];
-    $backendHostName = $params['backend_hostname'][$num];
-    $backendPort     = $params['backend_port'][$num];
-
-    if ($backendHostName != '') {
-        $conStr = "dbname=$healthCheckDb user=$healthCheckUser host=$backendHostName port=$backendPort" ;
-    } else {
-        $conStr = "dbname=$healthCheckDb port=$backendPort user=$healthCheckUser" ;
-    }
-
-    $conn = @pg_connect($conStr);
+    $conn = @pg_connect(conStr($num));
 
     if ($conn == FALSE) {
         @pg_close($conn);
@@ -264,20 +262,7 @@ function NodeStandby($num)
         return -1;
     }
 
-    $params = readHealthCheckParam();
-
-    $healthCheckUser = $params['health_check_user'];
-    $backendHostName = $params['backend_hostname'][$num];
-    $backendPort     = $params['backend_port'][$num];
-    $healthCheckDb = 'template1';
-
-    if ($backendHostName != '') {
-        $conStr = "dbname=$healthCheckDb user=$healthCheckUser host=$backendHostName port=$backendPort" ;
-    } else {
-        $conStr = "dbname=$healthCheckDb port=$backendPort user=$healthCheckUser" ;
-    }
-
-    $conn = @pg_connect($conStr);
+    $conn = @pg_connect(conStr($num, 'stream'));
 
     if ($conn == FALSE) {
         @pg_close($conn);
@@ -286,6 +271,7 @@ function NodeStandby($num)
 
     $res = pg_query($conn, 'SELECT pg_is_in_recovery()');
     if (!pg_result_status($res) == PGSQL_TUPLES_OK) {
+        @pg_close($conn);
         return -1;
     }
 
@@ -303,19 +289,40 @@ function NodeStandby($num)
 }
 
 /**
- * Read parameter from pgpool.conf using health check
- *
- * @return  array
+ * Create connection str for pg_connect()
  */
-function readHealthCheckParam()
+function conStr($num, $mode = NULL)
 {
+    // check user info
+    if ($mode == 'stream' && paramExists('sr_check_user')) {
+        $params = readConfigParams(array('sr_check_user',
+                                         'sr_check_password'));
+        $user     = $params['sr_check_user'];
+        $password = $params['sr_check_password'];
 
-    $params = readConfigParams(array('health_check_user',
-                                     'backend_hostname',
+    } else {
+        $params = readConfigParams(array('health_check_user',
+                                         'health_check_password'));
+        $user     = $params['health_check_user'];
+        $password = (isset($params['health_check_user'])) ?
+                    $params['health_check_pasword'] : NULL;
+    }
+
+    // backkend info
+    $params = readConfigParams(array('backend_hostname',
                                      'backend_port',
                                      'backend_weight'));
+    $conStr = array();
+    if ($params['backend_hostname'][$num] != '') {
+        $conStr[] = "host={$params['backend_hostname'][$num]} ";
+    }
+    $conStr[] = "port='{$params['backend_port'][$num]}'";
+    $conStr[] = "dbname='template1'";
+    $conStr[] = "user='{$user}'";
+    $conStr[] = "password='{$password}'";
 
-    return $params;
+    $conStr = implode($conStr, ' ');
+    return $conStr;
 }
 
 /**
@@ -354,7 +361,7 @@ function isReplicationMode()
 {
     $params = readConfigParams(array('replication_mode'));
 
-    if ($params['replication_mode'] == 'true') {
+    if (isTrue($params['replication_mode'])) {
         return TRUE;
     } else {
         return FALSE;
@@ -370,7 +377,7 @@ function isMasterSlaveMode()
 {
     $params = readConfigParams(array('master_slave_mode'));
 
-    if ($params['master_slave_mode'] == 'on') {
+    if (isTrue($params['master_slave_mode'])) {
         return TRUE;
     } else {
         return FALSE;
@@ -400,6 +407,8 @@ function useStreaming()
  */
 function useSyslog()
 {
+    if (!paramExists('log_destination')) { return FALSE; }
+
     $params = readConfigParams(array('log_destination'));
 
     if ($params['log_destination'] == 'syslog') {
@@ -439,6 +448,7 @@ function readConfigParams($paramList = FALSE)
             $key = trim($key);
             $value = trim($value);
 
+            // params about backend nodes
             if (preg_match("/^backend_hostname/", $key)) {
                 $num = str_replace('backend_hostname', '', $key);
                 $configParam['backend_hostname'][$num] = str_replace("'", "", $value);
@@ -455,6 +465,23 @@ function readConfigParams($paramList = FALSE)
                 $num = str_replace('backend_data_directory', '', $key);
                 $configParam['backend_data_directory'][$num] =str_replace("'", "", $value);
 
+            } elseif (preg_match("/^backend_flag/", $key)) {
+                $num = str_replace('backend_flag', '', $key);
+                $configParam['backend_flag'][$num] =str_replace("'", "", $value);
+
+            // params about watchdog monitoring
+            } elseif (preg_match("/^other_pgpool_hostname/", $key)) {
+                $num = str_replace('other_pgpool_hostname', '', $key);
+                $configParam['other_pgpool_hostname'][$num] = str_replace("'", "", $value);
+
+            } elseif (preg_match("/^other_pgpool_port/", $key)) {
+                $num = str_replace('other_pgpool_port', '', $key);
+                $configParam['other_pgpool_port'][$num] = $value;
+
+            } elseif (preg_match("/^other_wd_port/", $key)) {
+                $num = str_replace('other_wd_port', '', $key);
+                $configParam['other_wd_port'][$num] = $value;
+
             } else {
                 $configParam[$key] = str_replace("'", "", $value);
             }
@@ -466,13 +493,20 @@ function readConfigParams($paramList = FALSE)
             if (isset($configParam[$key])) {
                 $results[$key] = $configParam[$key];
             } else {
-                include('definePgpoolConfParam.php');
+                require_once('definePgpoolConfParam.php');
                 if(!preg_match("/^backend_hostname/",       $key) &&
                    !preg_match("/^backend_port/",           $key) &&
                    !preg_match("/^backend_weight/",         $key) &&
-                   !preg_match("/^backend_data_directory/", $key))
+                   !preg_match("/^backend_data_directory/", $key) &&
+                   !preg_match("/^backend_flag/",           $key) &&
+                   !preg_match("/^other_pgpool_hostname/",  $key) &&
+                   !preg_match("/^other_pgpool_port/",      $key) &&
+                   !preg_match("/^other_wd_port/",          $key)
+                   )
                 {
-                    $results[$key] = $pgpoolConfigParam[$key]['default'];
+                    if (isset($configParam[$key])) {
+                        $results[$key] = $configParam[$key]['default'];
+                    }
                 }
             }
         }
@@ -491,4 +525,135 @@ function isPipe($str)
     return (strpos($str, '|') !== FALSE);
 }
 
+function isTrue($value)
+{
+    return in_array($value, array('on', 'true'));
+}
+
+/* check version */
+function hasWatchdog()
+{
+    return (3.2 <= _PGPOOL2_VERSION);
+}
+
+function hasMemqcache()
+{
+    return (3.2 <= _PGPOOL2_VERSION);
+}
+// pgpool has pcp_promote_node ?
+function hasPcpPromote()
+{
+    return (3.1 <= _PGPOOL2_VERSION);
+}
+
+function paramExists($param)
+{
+    $add_version = $del_version = 0;
+    switch ($param) {
+        /* Add */
+
+        // params added in 3.2
+        case 'health_check_max_retries':
+        case 'health_check_retry_delay':
+        case 'use_watchdog':
+        case 'trusted_servers':
+        case 'delegate_IP':
+        case 'wd_hostname':
+        case 'wd_port':
+        case 'wd_interval':
+        case 'ping_path':
+        case 'ifconfig_path':
+        case 'if_up_cmd':
+        case 'if_down_cmd':
+        case 'arping_path':
+        case 'arping_cmd':
+        case 'wd_life_point':
+        case 'wd_lifecheck_query':
+        case 'memory_cache_enabled':
+        case 'memqcache_method':
+        case 'memqcache_memcached_host':
+        case 'memqcache_memcached_port':
+        case 'memqcache_total_size':
+        case 'memqcache_max_num_cache':
+        case 'memqcache_expire':
+        case 'memqcache_auto_cache_invalidation':
+        case 'memqcache_maxcache':
+        case 'memqcache_cache_block_size':
+        case 'memqcache_oiddir':
+        case 'white_memqcache_table_lsit':
+        case 'black_memqcache_table_list':
+        case 'relcache_size':
+        case 'check_temp_table':
+            $add_version = 3.2;
+            break;
+
+        // params added in 3.1
+        case 'follow_master_command':
+        case 'log_destination':
+        case 'syslog_facility':
+        case 'syslog_ident':
+        case 'debug_level':
+        case 'sr_check_period':
+        case 'sr_check_user':
+        case 'sr_check_password':
+        case 'health_check_password':
+        case 'relcache_expire':
+        case 'backend_flag':
+            $add_version = 3.1;
+            break;
+
+        // params added in 3.0
+        case 'master_slave_sub_mode':
+        case 'delay_threshold':
+        case 'log_standby_delay':
+        case 'debug_level':
+        case 'failover_if_affected_tuples_mismatch':
+        case 'white_function_list':
+        case 'black_function_list':
+            $add_version = 3.0;
+            break;
+
+        // params added in 2.3
+        case 'fail_over_on_backend_error':
+        case 'log_per_node_statement':
+        case 'lobj_lock_table':
+        case 'ssl':
+        case 'ssl_key':
+        case 'ssl_cert':
+        case 'ssl_ca_cert':
+        case 'ssl_ca_cert_dir':
+            $add_version = 2.3;
+            break;
+
+        // params added in 2.2
+        case 'pid_file_name':
+        case 'client_idle_limit_in_recovery':
+            $add_version = 2.2;
+            break;
+
+        /* Delete */
+
+        // params deleted in 3.2
+        case 'enable_query_cache':
+            $del_version = 3.2;
+            break;
+
+        // params deleted in 3.0
+        case 'backend_socket_dir':
+            $del_version = 3.0;
+            break;
+
+        // params deleted in 2.1
+        case 'replication_timeout':
+            $del_version = 2.1;
+            break;
+    }
+
+    if ($add_version && $add_version <= _PGPOOL2_VERSION) {
+        return TRUE;
+    } elseif ($del_version && _PGPOOL2_VERSION < $del_version) {
+        return TRUE;
+    }
+    return FALSE;
+}
 ?>
